# C++ API Reference

The C++ API provides high-performance implementations of the LZSS factorization algorithms. This documentation is automatically generated from the C++ source code.

```{eval-rst}
.. toctree::
   :maxdepth: 2
   :caption: C++ API Reference
   
   api/cpp_api
```